package com.huimv.cattle.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.cattle.mapper.IndustryOutputMapper;
import com.huimv.cattle.mapper.StockMapper;
import com.huimv.cattle.mapper.SysRegionCounTownVillMapper;
import com.huimv.cattle.pojo.IndustryOutput;
import com.huimv.cattle.pojo.Overview;
import com.huimv.cattle.mapper.OverviewMapper;
import com.huimv.cattle.pojo.Stock;
import com.huimv.cattle.service.OverviewService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.cattle.token.TokenSign;
import com.huimv.cattle.utils.FarmCodeUtils;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-12-15
 */
@Service
public class OverviewServiceImpl extends ServiceImpl<OverviewMapper, Overview> implements OverviewService {

    @Autowired
    private OverviewMapper overviewMapper;
    @Autowired
    private SysRegionCounTownVillMapper sysRegionCounTownVillMapper;
    @Autowired
    private StockMapper stockMapper;
    @Autowired
    private IndustryOutputMapper industryOutputMapper;

    @Override
    public Result overList(HttpServletRequest httpServletRequest,Map<String, String> paramsMap) {
        String farmCode = FarmCodeUtils.getFarmCode(paramsMap.get("farmCode"), httpServletRequest);
        List<Overview> overviews = overviewMapper.selectList(new QueryWrapper<Overview>().eq("farm_code",farmCode));
        int stockCount=0;
        int outCount=0;
        int breedCount=0;
        int farmCount=0;
        int outputValue=0;
        int allMoney =0;
        JSONObject jsonObject = new JSONObject();
        if (overviews.size()==0) {
            jsonObject.put("stockCount", 0);
            jsonObject.put("outCount", 0);
            jsonObject.put("breedCount", 0);
            jsonObject.put("farmCount", 0);
            jsonObject.put("outputValue", 0);
            jsonObject.put("variety", 0);
        } else {
            for (int i = 0; i < overviews.size(); i++) {
                stockCount = stockCount + overviews.get(i).getStockCount();
                outCount = outCount + overviews.get(i).getOutCount();
                breedCount = breedCount + overviews.get(i).getBreedCount();
                farmCount = farmCount + overviews.get(i).getFarmCount();
                outputValue=outputValue+overviews.get(i).getOutputValue().intValue();
            }
            Stock stock = stockMapper.selectOne(new QueryWrapper<Stock>().eq("farm_code", "0"));
            List<IndustryOutput> money = industryOutputMapper.selectList(new QueryWrapper<IndustryOutput>().eq("farm_code", "0"));
            for (IndustryOutput industryOutput : money) {
                allMoney +=industryOutput.getSalesMoney().intValue();
            }
            jsonObject.put("stockCount", stock.getFatStock()+stock.getCowStock()+stock.getBullStock());
            jsonObject.put("outCount", outCount);
            jsonObject.put("breedCount", stock.getBullStock());
            jsonObject.put("farmCount",farmCount);
            jsonObject.put("outputValue", allMoney);
            jsonObject.put("variety",overviews.get(0).getVariety());
        }
        return new Result(ResultCode.SUCCESS,jsonObject);
    }

    @Override
    public Result add(HttpServletRequest httpServletRequest,Map<String, String> paramsMap) {
        String farmCode =paramsMap.get("farmCode");
        if (farmCode==null) {
            farmCode = TokenSign.getFarmCode(httpServletRequest);
        }
        QueryWrapper<Overview> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_code", farmCode);
        Overview overList = overviewMapper.selectOne(queryWrapper);
       // Overview overList = overviewMapper.getOverList();
        if (ObjectUtil.isEmpty(overList)) {
            Overview overview = new Overview();
            overview.setStockCount(Integer.parseInt(paramsMap.get("stockCount")));
            overview.setOutCount(Integer.parseInt(paramsMap.get("outCount")));
            overview.setBreedCount(Integer.parseInt(paramsMap.get("breedCount")));
            overview.setFarmCount(Integer.parseInt(paramsMap.get("farmCount")));
            BigDecimal bg = new BigDecimal(paramsMap.get("outputValue"));
            overview.setOutputValue(bg);
            overview.setVariety(paramsMap.get("variety"));
            overview.setFarmCode(farmCode);
            overviewMapper.insert(overview);
            return new Result(ResultCode.SUCCESS,"添加成功");
        } else {
            overList.setStockCount(Integer.parseInt(paramsMap.get("stockCount")));
            overList.setOutCount(Integer.parseInt(paramsMap.get("outCount")));
            overList.setBreedCount(Integer.parseInt(paramsMap.get("breedCount")));
            overList.setFarmCount(Integer.parseInt(paramsMap.get("farmCount")));
            BigDecimal bg = new BigDecimal(paramsMap.get("outputValue"));
            overList.setOutputValue(bg);
            overList.setVariety(paramsMap.get("variety"));
            overviewMapper.updateById(overList);
            return new Result(ResultCode.SUCCESS,"修改成功");
        }
    }

    @Override
    public Result getListOverview(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmCode =paramsMap.get("farmCode");
        if (farmCode==null) {
            farmCode = TokenSign.getFarmCode(httpServletRequest);
        }
        QueryWrapper<Overview> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_code", farmCode);
        Overview overview = overviewMapper.selectOne(queryWrapper);
        JSONObject jsonObject = new JSONObject();
        if (ObjectUtil.isEmpty(overview)) {
            jsonObject.put("stockCount", 0);
            jsonObject.put("outCount", 0);
            jsonObject.put("breedCount", 0);
            jsonObject.put("farmCount", 0);
            jsonObject.put("outputValue", 0);
            jsonObject.put("variety", 0);
        } else {
            jsonObject.put("stockCount", overview.getStockCount());
            jsonObject.put("outCount", overview.getOutCount());
            jsonObject.put("breedCount", overview.getBreedCount());
            jsonObject.put("farmCount", overview.getFarmCount());
            jsonObject.put("outputValue", overview.getOutputValue());
            jsonObject.put("variety", overview.getVariety());
        }
        return new Result(ResultCode.SUCCESS,jsonObject);
    }

    @Override
    public Result getListOverviewScreen(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmCode =paramsMap.get("farmCode");
        if (farmCode==null) {
            farmCode = TokenSign.getFarmCode(httpServletRequest);
        }
        Overview overview = new Overview();
        Stock stock = new Stock();
        Integer allMoney=0;
        if (farmCode == null || farmCode.equals("0")){
            String cityCode = sysRegionCounTownVillMapper.listSub(farmCode);
            String[] city = cityCode.split(",");
            overview = overviewMapper.getListOverview(city);
            stock = stockMapper.getListStock(city);
            List<IndustryOutput> industryOutputs =  industryOutputMapper.getIndustryOutputScreen(city);
            for (IndustryOutput industryOutput : industryOutputs) {
                allMoney += industryOutput.getSalesMoney().intValue();
            }
        }else {
            QueryWrapper<Overview> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("farm_code", farmCode);
            overview = overviewMapper.selectOne(queryWrapper);
            stock = stockMapper.selectOne(new QueryWrapper<Stock>().eq("farm_code",farmCode));
            if (ObjectUtil.isEmpty(stock)){
                stock = new Stock();
                stock.setBullStock(0);
                stock.setCowStock(0);
                stock.setFatStock(0);
                stock.setFarmCode(farmCode);
                stockMapper.insert(stock);
            }

            List<IndustryOutput> industryOutputs = industryOutputMapper.selectList(new QueryWrapper<IndustryOutput>().eq("farm_code", farmCode));
            for (IndustryOutput industryOutput : industryOutputs) {
                allMoney += industryOutput.getSalesMoney().intValue();
            }
        }
        JSONObject jsonObject = new JSONObject();
        if (ObjectUtil.isEmpty(overview)) {
            jsonObject.put("stockCount", 0);
            jsonObject.put("outCount", 0);
            jsonObject.put("breedCount", 0);
            jsonObject.put("farmCount", 0);
            jsonObject.put("outputValue", 0);
            jsonObject.put("variety", 0);
        } else {
            jsonObject.put("stockCount", stock.getFatStock()+stock.getBullStock()+stock.getCowStock());
            jsonObject.put("outCount", overview.getOutCount());
            jsonObject.put("breedCount", stock.getBullStock());
            jsonObject.put("farmCount", overview.getFarmCount());
            jsonObject.put("outputValue", allMoney);
            jsonObject.put("variety", overview.getVariety());
        }
        return new Result(ResultCode.SUCCESS,jsonObject);
    }

    @Override
    public Integer getOutStock(JSONObject townJo) {
        QueryWrapper<Overview> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_code", townJo.getString("farmCode"));
        Overview overview = overviewMapper.selectOne(queryWrapper);
        if (ObjectUtil.isEmpty(overview)) {
            return 0;
        } else {
            return overview.getOutCount();
        }
    }

    @Override
    public Result getListOverviewVillageScreen(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmCode =paramsMap.get("farmCode");
        if (farmCode==null) {
            farmCode = TokenSign.getFarmCode(httpServletRequest);
        }
        Overview overview = new Overview();
        Stock stock = new Stock();
        String cityCode ="";
        String subCityCode="";
        Integer allMoney =0;
        List<String> subCityList = new ArrayList<>();
        if (farmCode == null || farmCode.equals("0")){
            cityCode = sysRegionCounTownVillMapper.listSub(farmCode);
            String[] city = cityCode.split(",");
            for (String s : city) {
                subCityCode = sysRegionCounTownVillMapper.listSub(s);
                String[] strings = subCityCode.split(",");
                for (String string : strings) {
                    subCityList.add(string);
                }
            }
            String[] subCity = subCityList.toArray(new String[subCityList.size()]);
            overview = overviewMapper.getListOverview(subCity);
            stock = stockMapper.getListStock(subCity);
            List<IndustryOutput> industryOutputScreen = industryOutputMapper.getIndustryOutputScreen(subCity);
            for (IndustryOutput industryOutput : industryOutputScreen) {
                allMoney +=industryOutput.getSalesMoney().intValue();
            }
        }else {
            cityCode = sysRegionCounTownVillMapper.listSub(farmCode);
            String[] city = cityCode.split(",");
            overview = overviewMapper.getListOverview(city);
            stock = stockMapper.getListStock(city);
            List<IndustryOutput> industryOutputScreen = industryOutputMapper.getIndustryOutputScreen(city);
            for (IndustryOutput industryOutput : industryOutputScreen) {
                allMoney +=industryOutput.getSalesMoney().intValue();
            }
        }

        JSONObject jsonObject = new JSONObject();
        if (ObjectUtil.isEmpty(overview)) {
            jsonObject.put("stockCount", 0);
            jsonObject.put("outCount", 0);
            jsonObject.put("breedCount", 0);
            jsonObject.put("farmCount", 0);
            jsonObject.put("outputValue", 0);
            jsonObject.put("variety", 0);
        } else {
            if (ObjectUtil.isNotEmpty(stock)){
                jsonObject.put("stockCount", stock.getFatStock()+stock.getBullStock()+stock.getCowStock());
                jsonObject.put("breedCount", stock.getBullStock());
            }else {
                jsonObject.put("stockCount", 0);
                jsonObject.put("breedCount", 0);
            }
            jsonObject.put("outCount", overview.getOutCount());
            jsonObject.put("farmCount", overview.getFarmCount());
            jsonObject.put("outputValue", allMoney);
            jsonObject.put("variety", overview.getVariety());
        }
        return new Result(ResultCode.SUCCESS,jsonObject);
    }

    @Override
    public Integer getAllOutStock(JSONObject jsonObject) {
        String farmCode = jsonObject.getString("farmCode");
        String[] city = sysRegionCounTownVillMapper.listSub(farmCode).split(",");
        Integer allOutStock =0;
        for (String s : city) {
            Overview overview = overviewMapper.selectOne(new QueryWrapper<Overview>().eq("farm_code", s));
            if (ObjectUtil.isEmpty(overview)){
                overview = new Overview();
                overview.setFarmCode(s);
                overview.setOutCount(0);
                overview.setBreedCount(0);
                overview.setOutputValue(BigDecimal.ZERO);
                overview.setVariety("0");
                overview.setFarmCount(0);
                overview.setStockCount(0);
                overviewMapper.insert(overview);
            }
            Integer outCount = overview.getOutCount();
            if (ObjectUtil.isEmpty(outCount)){
                outCount = 0;
            }
            allOutStock += outCount;
        }
        if (ObjectUtil.isEmpty(allOutStock)){
            return 0;
        }else {
            return allOutStock;
        }
    }
}
