package com.huimv.cattle.service.impl;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
//import com.huimv.breed.common.utils.ResultUtil;
import com.huimv.cattle.mapper.*;
import com.huimv.cattle.pojo.*;
import com.huimv.cattle.pojo.vo.TreeFarm;
import com.huimv.cattle.service.DataSourceService;
import com.huimv.cattle.service.StockService;
import com.huimv.cattle.service.SysFarmService;
import com.huimv.cattle.token.TokenSign;
import com.huimv.cattle.utils.ChineseCharacterUtil;
import com.huimv.cattle.utils.ResultUtil;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
//import com.huimv.saas.admin.mapper.SysFarmMapper;
//import com.huimv.saas.admin.mapper.SysUserAccountMapper;
//import com.huimv.saas.admin.pojo.SysFarm;
//import com.huimv.saas.admin.pojo.SysUserAccount;
//import com.huimv.saas.admin.service.SysFarmService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-09-26
 */
@Service
public class SysFarmServiceImpl extends ServiceImpl<SysFarmMapper, SysFarm> implements SysFarmService {
    @Resource
    private SysFarmMapper sysFarmMapper;
    @Resource
    private SysUserAccountMapper sysUserAccountMapper;
    @Resource
    private SysFarmServiceMapper sysFarmServiceMapper;
    @Resource
    private SysUserGroupMapper sysUserGroupMapper;
    @Resource
    private ResultUtil resultUtil;
    @Value("${manager.defaultPassword}")
    private String defaultPassword;
    @Resource
    private DataSourceService dataSourceService;
    @Resource
    private StockService stockService;
    @Resource
    private RestTemplate restTemplate;
    @Autowired
    private SysRegionCounTownVillMapper sysRegionCounTownVillMapper;

    @Override
    public Result initFarmFlow(HttpServletRequest request, Map<String, String> paramsMap) {
        //--step1:创建牧场；
        //--step2:根据默认牧场管理员权限组创建牧场账号；

        return null;
    }

    @Override
    public Result listFarm(HttpServletRequest request, Map<String, String> paramsMap) {
        String pageNo = paramsMap.get("pageNo") + "";
        if (pageNo == null) {
            pageNo = "1";
        }
        String pageSize = paramsMap.get("pageSize") + "";
        if (pageSize == null) {
            pageSize = "10";
        }
        //牧场名称
        String farmName = paramsMap.get("farmName");
        QueryWrapper<SysFarm> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(StringUtils.isNotBlank(farmName), "farm_name", farmName);
        queryWrapper.orderByAsc("id");
        Page<SysFarm> page = new Page<>(Integer.parseInt(pageNo), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS, sysFarmMapper.selectPage(page, queryWrapper));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result newFarm(HttpServletRequest request, Map<String, String> paramsMap) {
        //
        String farmStatus = paramsMap.get("farmStatus");
        if (StringUtils.isBlank(farmStatus)) {
            farmStatus = "1";
        }
        String farmCode = paramsMap.get("farmCode");
        List<SysFarm> farms = sysFarmMapper.selectList(new QueryWrapper<SysFarm>().eq("farm_code", farmCode));
        System.out.println(farms.toString());
        if (ObjectUtil.isNotEmpty(farms)) {
            return new Result(10010, "牧场编号已存在", false);
        }
        SysRegionCounTownVill sysRegionCounTownVill = new SysRegionCounTownVill();
        sysRegionCounTownVill.setCityCode(farmCode);
        SysRegionCounTownVill city = sysRegionCounTownVillMapper.selectOne(new QueryWrapper<SysRegionCounTownVill>().eq("city_code", "0"));
        String cityCodeSub = city.getCityCodeSub();
        String newCityCodeSub = cityCodeSub +","+farmCode;
        city.setCityCodeSub(newCityCodeSub);
        UpdateWrapper<SysRegionCounTownVill> updateWrapper = new UpdateWrapper<>();
        updateWrapper.eq("city_code","0");
        sysRegionCounTownVillMapper.update(city,updateWrapper);
        sysRegionCounTownVillMapper.insert(sysRegionCounTownVill);

        SysFarm sysFarm = new SysFarm();
        sysFarm.setFarmName(paramsMap.get("farmName"));
        sysFarm.setFarmCode(paramsMap.get("farmCode"));
        sysFarm.setLinkman(paramsMap.get("linkman"));
        sysFarm.setPhone(paramsMap.get("phone"));
        sysFarm.setAddress(paramsMap.get("address"));
        sysFarm.setFarmStatus(Integer.parseInt(farmStatus));
        sysFarm.setRemark(paramsMap.get("remark"));
        sysFarm.setParentCode("0");
        sysFarm.setType(1);
        sysFarm.setAdcode(paramsMap.get("adCode"));
        return resultUtil.getResult(sysFarmMapper.insert(sysFarm));
    }

    @Override
    public Result editFarm(HttpServletRequest request, Map<String, String> paramsMap) {
        //
        String farmStatus = paramsMap.get("farmStatus");
        if (StringUtils.isBlank(farmStatus)) {
            farmStatus = "1";
        }
        SysFarm sysFarm = new SysFarm();
        sysFarm.setId(Integer.parseInt(paramsMap.get("id")));
        sysFarm.setFarmName(paramsMap.get("farmName"));
        sysFarm.setFarmCode(paramsMap.get("farmCode"));
        sysFarm.setLinkman(paramsMap.get("linkman"));
        sysFarm.setPhone(paramsMap.get("phone"));
        sysFarm.setAddress(paramsMap.get("address"));
        sysFarm.setFarmStatus(Integer.parseInt(farmStatus));
        sysFarm.setRemark(paramsMap.get("remark"));
        sysFarm.setAdcode(paramsMap.get("adCode"));
        return resultUtil.getResult(sysFarmMapper.updateById(sysFarm));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result removeFarm(HttpServletRequest request, Map<String, String> paramsMap) {
        String farmCode = paramsMap.get("farmCode");
        String parentCode = paramsMap.get("parentCode");
        String type = paramsMap.get("type");

        Integer integer = Math.toIntExact(sysFarmMapper.selectCount(new QueryWrapper<SysFarm>().eq("parent_code", farmCode)));
        if (integer > 0){
            return new Result(10001,"删除失败，存在下属乡镇",false);
        }else {
            sysRegionCounTownVillMapper.delete(new QueryWrapper<SysRegionCounTownVill>().eq("city_code",farmCode));
        }

        if (type.equals("1")){
            SysRegionCounTownVill sysRegionCounTownVill = sysRegionCounTownVillMapper.selectOne(new QueryWrapper<SysRegionCounTownVill>().eq("city_code", "0"));
            String subCity = sysRegionCounTownVill.getCityCodeSub();
            String newSubCity ="";

            String[] array = subCity.split(",");
            List<String> arrList = Arrays.asList(array);
            List<String> arrList1 = new ArrayList<>(arrList);
            arrList1.remove(farmCode);

            String[] strings = new String[arrList1.size()];
            String[] newArray = arrList1.toArray(strings);

            for (int j = 0; j < newArray.length;j++){
                newSubCity+=newArray[j]+",";
            }
            if (!"".equals(newSubCity)){
                newSubCity=newSubCity.substring(0, newSubCity.length()-1);
            }
            sysRegionCounTownVill.setCityCodeSub(newSubCity);
            sysRegionCounTownVillMapper.update(sysRegionCounTownVill,new UpdateWrapper<SysRegionCounTownVill>().eq("city_code","0"));
        }else {
            SysRegionCounTownVill sysRegionCounTownVill = sysRegionCounTownVillMapper.selectOne(new QueryWrapper<SysRegionCounTownVill>().eq("city_code", parentCode));
            String subCity = sysRegionCounTownVill.getCityCodeSub();
            String newSubCity ="";

            String[] array = subCity.split(",");
            List<String> arrList = Arrays.asList(array);
            List<String> arrList1 = new ArrayList<>(arrList);
            arrList1.remove(farmCode);

            String[] strings = new String[arrList1.size()];
            String[] newArray = arrList1.toArray(strings);

            for (int j = 0; j < newArray.length;j++){
                newSubCity+=newArray[j]+",";
            }
            if (!"".equals(newSubCity)){
                newSubCity=newSubCity.substring(0, newSubCity.length()-1);
            }
            sysRegionCounTownVill.setCityCodeSub(newSubCity);
            sysRegionCounTownVillMapper.update(sysRegionCounTownVill,new UpdateWrapper<SysRegionCounTownVill>().eq("city_code",parentCode));
        }
        return resultUtil.getResult(sysFarmMapper.delete(new QueryWrapper<SysFarm>().eq("farm_code",farmCode)));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result resetPassword(HttpServletRequest request, Map<String, String> paramsMap) {
        String ids = paramsMap.get("farmCodes");
        String[] idArray = ids.split(",");
        int rows = 0;
        for (String id : idArray) {
            SysUserAccount SysUserAccount = new SysUserAccount();
            SysUserAccount.setFarmCode(id);
            SysUserAccount.setPassword(defaultPassword);
            rows += sysUserAccountMapper.updateById(SysUserAccount);
        }
        return resultUtil.getResult(rows);
    }

    @Override
    public Result getAllFarmId(HttpServletRequest request, Map<String, String> paramsMap) {
        QueryWrapper<SysFarm> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("id");
        List<SysFarm> sysFarmList = sysFarmMapper.selectList(queryWrapper);
        StringBuilder idSb = new StringBuilder();
        for (SysFarm farmData : sysFarmList) {
            if (idSb.length() > 0) {
                idSb.append(",");
            }
            idSb.append(farmData.getFarmCode());
        }
        if (idSb.length() > 0) {
            return new Result(ResultCode.SUCCESS, idSb.toString());
        } else {
            return new Result(ResultCode.FAIL);
        }
    }

    @Override
    public Result listAllTownsCount(HttpServletRequest request) {
        /////////////////////////////////////////////////////////////////////////
        //读取所有乡镇
        //统计所有存栏（手填报或者从养殖云获取）
        /////////////////////////////////////////////////////////////////////////

        //读取所有乡镇
        JSONArray allTownsJa = getAllTowns();
        JSONArray allVillageJa = getAllVillage();
        System.out.println("allTownsJa=" + allTownsJa);
        if (allTownsJa.size() == 0) {
            return new Result(0, "当前未查询到任何乡镇数据.", false);
        }
        //读取模式切换
        DataSource dataSource = dataSourceService.getDataSourceStatus();
        if (dataSource.getDsStatus() == 2){
            return getStockFromBreedCloud(allTownsJa);
        }else if (dataSource.getViewType() == 3){
            return stockService.getAllVillageStock(request,allVillageJa);
        }else {
            return stockService.getAllTownStock(request, allTownsJa);
        }
//        //view=2,显示镇汇总数据
//        if (dataSource.getDsStatus() == 1) {
//            //status=1,显示镇（手填）数据
//            return stockService.getAllTownStock(request, allTownsJa);
//        } else {
//            //status=2,显示镇汇总（养殖云）数据
//            return getStockFromBreedCloud(allTownsJa);
//        }
    }

    @Override
    public Result listTownFarm(HttpServletRequest request, Map<String, String> paramsMap) {
        String farmCode = paramsMap.get("farmCode");
        if (farmCode == null) {
            farmCode = TokenSign.getFarmCode(request);
        }
        if (farmCode == null || farmCode.equals("0")){
            List<SysFarm> sysFarmList = sysFarmMapper.selectList(new QueryWrapper<SysFarm>().eq("parent_code",farmCode));
            return new Result(ResultCode.SUCCESS,sysFarmList);
        }else {
            List<SysFarm> sysFarmList = sysFarmMapper.selectList(new QueryWrapper<SysFarm>().eq("farm_code",farmCode));
            return new Result(ResultCode.SUCCESS,sysFarmList);
        }
    }

    @Override
    public Result listVillageFarm(HttpServletRequest request, Map<String, String> paramsMap) {
        String farmCode = paramsMap.get("farmCode");
        String farmName = paramsMap.get("farmName");
        if (farmCode == null) {
            farmCode = TokenSign.getFarmCode(request);
        }
        if (StringUtils.isEmpty(farmName)) {
            farmName = "";
        }
        if (farmCode == null || farmCode.equals("0")){
            List<SysFarm> farms = sysFarmMapper.selectList(new QueryWrapper<SysFarm>().like("farm_name",farmName));
            List<TreeFarm> treeFarms = parseBizBaseArea(farms);
            return new Result(ResultCode.SUCCESS,treeFarms);
        }else {
            List<SysFarm> farms = sysFarmMapper.selectList(new QueryWrapper<SysFarm>().eq("farm_code", farmCode).or().eq("parent_code", farmCode));
            List<TreeFarm> treeFarms = parseBizBaseArea(farms);
            return new Result(ResultCode.SUCCESS,treeFarms);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result newSub(HttpServletRequest request, Map<String, String> paramsMap) {
        //
        String farmStatus = paramsMap.get("farmStatus");
        if (StringUtils.isBlank(farmStatus)) {
            farmStatus = "1";
        }
        String farmCode = paramsMap.get("farmCode");
        List<SysFarm> farms = sysFarmMapper.selectList(new QueryWrapper<SysFarm>().eq("farm_code", farmCode));
        System.out.println(farms.toString());
        if (ObjectUtil.isNotEmpty(farms)) {
            return new Result(10010, "牧场编号已存在", false);
        }
        String parentCode = paramsMap.get("parentCode");

        SysRegionCounTownVill city = sysRegionCounTownVillMapper.selectOne(new QueryWrapper<SysRegionCounTownVill>().eq("city_code",parentCode));
        String cityCodeSub = city.getCityCodeSub();
        String newCityCodeSub = cityCodeSub +","+farmCode;
        city.setCityCodeSub(newCityCodeSub);
        UpdateWrapper<SysRegionCounTownVill> updateWrapper = new UpdateWrapper<>();
        updateWrapper.eq("city_code",parentCode);
        sysRegionCounTownVillMapper.update(city,updateWrapper);

        SysFarm sysFarm = new SysFarm();
        sysFarm.setFarmName(paramsMap.get("farmName"));
        sysFarm.setFarmCode(paramsMap.get("farmCode"));
        sysFarm.setLinkman(paramsMap.get("linkman"));
        sysFarm.setPhone(paramsMap.get("phone"));
        sysFarm.setAddress(paramsMap.get("address"));
        sysFarm.setFarmStatus(Integer.parseInt(farmStatus));
        sysFarm.setRemark(paramsMap.get("remark"));
        sysFarm.setParentCode(parentCode);
        sysFarm.setType(2);
        sysFarm.setAdcode(paramsMap.get("adCode"));
        return resultUtil.getResult(sysFarmMapper.insert(sysFarm));
    }

    @Override
    @Transactional(rollbackFor = RuntimeException.class)
    public Result addFarm(Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String adcode = this.getOne(new QueryWrapper<SysFarm>().eq("farm_code", farmId)).getAdcode();
        String farms = paramsMap.get("farms");
        String[] farmCodes = farms.split(",");
        List<String> farmCodeList = new ArrayList<>();
        for (int i = 1; i <= farmCodes.length; i++) {
            if (i < 10){
                farmCodeList.add(farmId+"00"+i);
            }else {
                farmCodeList.add(farmId+"0"+i);
            }
        }
        int i = 0;
        for (String s : farmCodeList) {
            SysFarm sysFarm = new SysFarm();
            sysFarm.setFarmName(farmCodes[i]);
            sysFarm.setFarmCode(s);
            sysFarm.setLinkman("1");
            sysFarm.setPhone("123456");
            sysFarm.setAddress(farmCodes[i]);
            sysFarm.setFarmStatus(1);
            sysFarm.setAdcode(adcode);
            sysFarm.setParentCode(farmId);
            sysFarm.setType(2);
            this.save(sysFarm);
            com.huimv.cattle.pojo.SysFarmService farmService = new com.huimv.cattle.pojo.SysFarmService();
            farmService.setFarmName(farmCodes[i]);
            farmService.setFarmCode(s);
            farmService.setStartDate(new Date());
            farmService.setEndDate(getNextYearPreDay());
            farmService.setServiceCycle(12);
            farmService.setServiceStatus(1);
            farmService.setCurrentStatus(1);
            sysFarmServiceMapper.insert(farmService);

            SysUserAccount sysUserAccount = new SysUserAccount();
            sysUserAccount.setUserName(farmCodes[i]+"管理员");
            sysUserAccount.setMale(1);
            sysUserAccount.setMobile("123");
            sysUserAccount.setAccountClass(2);
            sysUserAccount.setAccountType(1);
            if (farmCodes[i].endsWith("村")){
                farmCodes[i] = farmCodes[i].substring(0,farmCodes[i].length() - 1);
            }
            sysUserAccount.setAccountName(ChineseCharacterUtil.convertHanzi2Pinyin(farmCodes[i],true));
            sysUserAccount.setPassword("123456");
            sysUserAccount.setFarmCode(s);
            sysUserAccount.setLoginStatus(1);
            sysUserAccountMapper.insert(sysUserAccount);
            SysUserGroup sysUserGroup = new SysUserGroup();
            sysUserGroup.setUserId(sysUserAccount.getId().intValue());
            sysUserGroup.setGroupId(23);
            sysUserGroupMapper.insert(sysUserGroup);
            i++;
        }
        String farmCodes1 = "";

        for (String s : farmCodeList) {
            farmCodes1+= s+",";
        }
        SysRegionCounTownVill sysRegionCounTownVill = sysRegionCounTownVillMapper.selectOne(new QueryWrapper<SysRegionCounTownVill>().eq("city_code", farmId));
        sysRegionCounTownVill.setCityCodeSub(farmCodes1);
        sysRegionCounTownVillMapper.updateById(sysRegionCounTownVill);
        return Result.SUCCESS();
    }

    @Override
    public Result addTown(Map<String, String> paramsMap) {
        String farms = paramsMap.get("farms");
        String[] farmCodes = farms.split(",");
        List<String> farmCodeList = new ArrayList<>();
        for (int i = 3; i <= farmCodes.length+2; i++) {
            if (i < 10){
                farmCodeList.add("6208"+"00"+i);
            }else {
                farmCodeList.add("6208"+"0"+i);
            }
        }
        int i = 0;
        for (String s : farmCodeList) {
            com.huimv.cattle.pojo.SysFarmService farmService = new com.huimv.cattle.pojo.SysFarmService();
            farmService.setFarmName(farmCodes[i]);
            farmService.setFarmCode(s);
            farmService.setStartDate(new Date());
            farmService.setEndDate(getNextYearPreDay());
            farmService.setServiceCycle(12);
            farmService.setServiceStatus(1);
            farmService.setCurrentStatus(1);
            sysFarmServiceMapper.insert(farmService);

            SysUserAccount sysUserAccount = new SysUserAccount();
            sysUserAccount.setUserName(farmCodes[i]+"管理员");
            sysUserAccount.setMale(1);
            sysUserAccount.setMobile("123");
            sysUserAccount.setAccountClass(1);
            sysUserAccount.setAccountType(1);
            if (farmCodes[i].endsWith("镇")|| farmCodes[i].endsWith("乡")){
                farmCodes[i] = farmCodes[i].substring(0,farmCodes[i].length() - 1);
            }
            sysUserAccount.setAccountName(ChineseCharacterUtil.convertHanzi2Pinyin(farmCodes[i],true));
            sysUserAccount.setPassword("123456");
            sysUserAccount.setFarmCode(s);
            sysUserAccount.setLoginStatus(1);
            sysUserAccountMapper.insert(sysUserAccount);
            SysUserGroup sysUserGroup = new SysUserGroup();
            sysUserGroup.setUserId(sysUserAccount.getId().intValue());
            sysUserGroup.setGroupId(24);
            sysUserGroupMapper.insert(sysUserGroup);
            i++;
        }
        return Result.SUCCESS();
    }

    public static Date getNextYearPreDay() {
        Calendar ca = Calendar.getInstance();//得到一个Calendar的实例
        ca.setTime(new Date());   //设置时间为当前时间
        ca.add(Calendar.YEAR, +1); //年份+1
        // ca.add(Calendar.MONTH, -1); // 月份-1
        ca.add(Calendar.DATE, -1); // 日期-1
        return ca.getTime();
    }

    //获取所有乡镇信息
    private JSONArray getAllTowns() {
        QueryWrapper<SysFarm> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("type",1);
        queryWrapper.orderByAsc("id");
        List<SysFarm> sysFarmList = sysFarmMapper.selectList(queryWrapper);
        JSONArray townsJa = new JSONArray();
        for (SysFarm farmData : sysFarmList) {
            JSONObject townJo = new JSONObject();
            townsJa.add(townJo);
            townJo.put("farmName", farmData.getFarmName());
            townJo.put("farmCode", farmData.getFarmCode());
            townJo.put("adCode", farmData.getAdcode());
            townJo.put("townCode", farmData.getAdcode().substring(farmData.getAdcode().lastIndexOf(",") + 1, farmData.getAdcode().length()));
        }
        return townsJa;
    }
    //获取所有乡镇信息
    private JSONArray getAllVillage() {
        QueryWrapper<SysFarm> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByAsc("id");
        queryWrapper.eq("parent_code","0");
        List<SysFarm> sysFarmList = sysFarmMapper.selectList(queryWrapper);
        JSONArray townsJa = new JSONArray();
        for (SysFarm farmData : sysFarmList) {
            JSONObject townJo = new JSONObject();
            townsJa.add(townJo);
            townJo.put("farmName", farmData.getFarmName());
            townJo.put("farmCode", farmData.getFarmCode());
            townJo.put("adCode", farmData.getAdcode());
            townJo.put("townCode", farmData.getAdcode().substring(farmData.getAdcode().lastIndexOf(",") + 1, farmData.getAdcode().length()));
        }
        return townsJa;
    }

    //显示镇汇总（养殖云）数据
    private Result getStockFromBreedCloud(JSONArray allTownsJa) {
        HttpHeaders httpHeaders = new HttpHeaders();
        MediaType type = MediaType.parseMediaType("application/json;charset=UTF-8");
        httpHeaders.setContentType(type);
        HashMap<String, Object> map = new HashMap<>();
        //这里提交的是区县编码或乡镇编码
        map.put("allTown", allTownsJa.toJSONString());
        HttpEntity<Map<String, Object>> objectHttpEntity = new HttpEntity<>(map, httpHeaders);
        //读取真实数据
        String remoteUrl = "http://123.60.134.84:10001/breed/api/v1.0.0/cattle/getStockByDivision2";
        ResponseEntity<String> entity = restTemplate.postForEntity(remoteUrl, objectHttpEntity, String.class);
        if (entity.getStatusCode().toString().contains("200")) {
            String body = entity.getBody();
//            System.out.println(body);
            JSONObject resultJo = JSON.parseObject(body);
//            System.out.println("resultJo=" + resultJo);
            return new Result(ResultCode.SUCCESS, resultJo.getJSONArray("data"));
        } else {
            return new Result(ResultCode.FAIL, "调取远程数据出错.");
        }
    }

    private List<TreeFarm> parseBizBaseArea(List<SysFarm> bizBaseAreas){
        //构建需要展示的树形节点结构
        Map<String, TreeFarm> nodeMap =bizBaseAreas.stream().map(farm -> {
            TreeFarm treeFarm = new TreeFarm();
            treeFarm.setId(farm.getId());
            treeFarm.setAdcode(farm.getAdcode());
            treeFarm.setAddress(farm.getAddress());
            treeFarm.setFarmCode(farm.getFarmCode());
            treeFarm.setFarmName(farm.getFarmName());
            treeFarm.setFarmStatus(farm.getFarmStatus());
            treeFarm.setLinkman(farm.getLinkman());
            treeFarm.setParentCode(farm.getParentCode());
            treeFarm.setChildNode(new ArrayList<>());
            treeFarm.setPhone(farm.getPhone());
            treeFarm.setRemark(farm.getRemark());
            treeFarm.setType(farm.getType());
            return treeFarm;
        }).collect(Collectors.toMap(TreeFarm::getFarmCode, b -> b,(k1, k2)->k1));
        //创建数组存父亲节点
        ArrayList<TreeFarm> roots = new ArrayList<>();
        //构建树形
        nodeMap.values().forEach(item->{
            String parentCode = item.getParentCode()+"";
            //父节点为空，说明当前节点就已经是父节点了 将该节点存起来
            if (nodeMap.get(parentCode) == null){
                roots.add(item);
            }else {
                //父节点 不为空，说明有父节点，拿到该节点的父节点的孩子节点（就是我自己),将该节点存起来
                nodeMap.get(parentCode).getChildNode().add(item);
            }
        });
        return roots;
    }
}
